==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/OriginRequestPolicyCookiesConfigCookiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.OriginRequestPolicyCookiesConfigCookiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class OriginRequestPolicyCookiesConfigCookiesArgs(
    public val items: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.OriginRequestPolicyCookiesConfigCookiesArgs> {
    override fun toJava():
        com.pulumi.aws.cloudfront.inputs.OriginRequestPolicyCookiesConfigCookiesArgs =
        com.pulumi.aws.cloudfront.inputs.OriginRequestPolicyCookiesConfigCookiesArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [OriginRequestPolicyCookiesConfigCookiesArgs].
 */
@PulumiTagMarker
public class OriginRequestPolicyCookiesConfigCookiesArgsBuilder internal constructor() {
    private var items: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("opxgrxxbgkjxvvtp")
    public suspend fun items(`value`: Output<List<String>>) {
        this.items = value
    }

    @JvmName("xhwadkprvyvqkcsb")
    public suspend fun items(vararg values: Output<String>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("wxqiijpxunmhlkdl")
    public suspend fun items(values: List<Output<String>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("xeewmorwauucdxho")
    public suspend fun items(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("lnftcnfffsagqaqy")
    public suspend fun items(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): OriginRequestPolicyCookiesConfigCookiesArgs =
        OriginRequestPolicyCookiesConfigCookiesArgs(
            items = items,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/OriginRequestPolicyCookiesConfigCookiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.OriginRequestPolicyCookiesConfigCookiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class OriginRequestPolicyCookiesConfigCookiesArgs(
    public val items: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.OriginRequestPolicyCookiesConfigCookiesArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.OriginRequestPolicyCookiesConfigCookiesArgs =
        com.pulumi.aws.cloudfront.inputs.OriginRequestPolicyCookiesConfigCookiesArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [OriginRequestPolicyCookiesConfigCookiesArgs].
 */
@PulumiTagMarker
public class OriginRequestPolicyCookiesConfigCookiesArgsBuilder internal constructor() {
    private var items: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("kwupsdexmsetarte")
    public suspend fun items(`value`: Output<List<String>>) {
        this.items = value
    }

    @JvmName("eontakcudxsprrjd")
    public suspend fun items(vararg values: Output<String>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("jegxsiayulghymkp")
    public suspend fun items(values: List<Output<String>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ahvkeboqagoxands")
    public suspend fun items(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("ohyhedjyvpmbxxcv")
    public suspend fun items(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): OriginRequestPolicyCookiesConfigCookiesArgs =
        OriginRequestPolicyCookiesConfigCookiesArgs(
            items = items,
        )
}
